==> engage-ui-0.27.7.tgz: package/src/components/Label/Label.tsx <==
import * as React from 'react';
import { themr, ThemedComponentClass } from '@friendsofreactjs/react-css-themr';
import { classNames } from '@shopify/react-utilities/styles';

import { Action } from '../../types';
import { buttonFrom } from '../Button';
import { LABEL } from '../ThemeIdentifiers';

import * as baseTheme from './Label.scss';

export { Action };

export interface Props {
  children?: any;
  // ID for the input.
  componentId: string;
  // Adds an action to the label.
  action?: Action;
  // Visually hide the label.
  hidden?: boolean;
  // To provide styling for label.
  componentStyle?: React.CSSProperties;
  // Extra class passed as a prop
  componentClass?: string;
  labelContainerClass?: string;
  // Theme to be injected via css-themr.
  theme?: any;
  // To make it required or not.
  required?: boolean;
  // To display label focused.
  focused?: boolean;
  // To display Initial value for the label.
  hasValue?: boolean;
}

export function labelID(id: string) {
  return `${id}Label`;
}

function label({
  children,
  componentId,
  action,
  hidden,
  required,
  hasValue,
  focused,
  componentStyle,
  componentClass = '',
  labelContainerClass = '',
  theme,
}: Props) {
  const className = classNames(
    theme.text,
    componentClass,
    hidden && theme.hidden,
    required && theme.required,
    !hasValue && theme.empty,
    focused && theme.focused
  );

  const labelClass = classNames(
    labelContainerClass,
    theme.label
  );

  const actionMarkup = action
    ? buttonFrom(action, { plain: true })
    : null;

  return (
    <div className={labelClass}>
      <label id={labelID(componentId)} htmlFor={componentId} className={className} style={componentStyle}>{children}</label>
      {actionMarkup}
    </div>
  );
}

export default themr(LABEL, baseTheme)(label) as ThemedComponentClass<Props, {}>;

==> engage-ui-1.4.0.tgz: package/src/components/Label/Label.tsx <==
import * as React from 'react';
import { themr, ThemedComponentClass } from '@friendsofreactjs/react-css-themr';
import { classNames } from '@shopify/react-utilities/styles';

import { Action } from '../../types';
import { buttonFrom } from '../Button';
import { LABEL } from '../ThemeIdentifiers';

import * as baseTheme from './Label.scss';

export { Action };

export interface Props {
  children?: any;
  // ID for the input.
  componentId: string;
  // Adds an action to the label.
  action?: Action;
  // Visually hide the label.
  hidden?: boolean;
  // To provide styling for label.
  componentStyle?: React.CSSProperties;
  // Extra class passed as a prop
  componentClass?: string;
  // Theme to be injected via css-themr.
  theme?: any;
  // To make it required or not.
  required?: boolean;
  // To display label focused.
  focused?: boolean;
  // To display Initial value for the label.
  hasValue?: boolean;
}

export function labelID(id: string) {
  return `${id}Label`;
}

function label({
  children,
  componentId,
  action,
  hidden,
  required,
  hasValue,
  focused,
  componentStyle,
  componentClass = '',
  theme,
}: Props) {
  const className = classNames(
    theme.text,
    componentClass,
    hidden && theme.hidden,
    required && theme.required,
    !hasValue && theme.empty,
    focused && theme.focused
  );

  const actionMarkup = action
    ? buttonFrom(action, { plain: true })
    : null;

  return (
    <div className={theme.label}>
      <label id={labelID(componentId)} htmlFor={componentId} className={className} style={componentStyle}>{children}</label>
      {actionMarkup}
    </div>
  );
}

export default themr(LABEL, baseTheme)(label) as ThemedComponentClass<Props, {}>;
